@@ -3,12 +3,8 @@ var classFl__Tiled__Image =
     [ "Fl_Tiled_Image", "classFl__Tiled__Image.html#a5721af8f1b9a9fbe542a3a6c297a8f11", null ],
     [ "~Fl_Tiled_Image", "classFl__Tiled__Image.html#a9d22f2345513330c2d21d11bb75f2087", null ],
     [ "color_average", "classFl__Tiled__Image.html#af42b9c458fa9799e039390ebf1193fad", null ],
-    [ "copy", "classFl__Tiled__Image.html#af091bc61560ef72f68ed9731ef9366db", null ],
     [ "copy", "classFl__Tiled__Image.html#a2e484f49ff399ced1c61a080c73243bd", null ],
     [ "desaturate", "classFl__Tiled__Image.html#ab94918248f14233d6e90d735aac03b18", null ],
-    [ "draw", "classFl__Tiled__Image.html#abb21f1b35e3581868d414f8d50dc40bb", null ],
     [ "draw", "classFl__Tiled__Image.html#a1b96f7b3ae9eeffabb7ba2504b286c13", null ],
-    [ "image", "classFl__Tiled__Image.html#a94b5af1f3b1a8ee1cf12929c5821d986", null ],
-    [ "alloc_image_", "classFl__Tiled__Image.html#ab1b2a8023f8e56c48fc85e56ae683893", null ],
-    [ "image_", "classFl__Tiled__Image.html#ab08a70c7933cee0afcc0b26a72c0f710", null ]
+    [ "image", "classFl__Tiled__Image.html#aa62151f76b5c50de24549c66189c237e", null ]
 ];
\ No newline at end of file
